summaryrefslogtreecommitdiff
path: root/src/pip/_vendor/platformdirs/macos.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/pip/_vendor/platformdirs/macos.py')
-rw-r--r--src/pip/_vendor/platformdirs/macos.py20
1 files changed, 13 insertions, 7 deletions
diff --git a/src/pip/_vendor/platformdirs/macos.py b/src/pip/_vendor/platformdirs/macos.py
index a01337c77..ec9751129 100644
--- a/src/pip/_vendor/platformdirs/macos.py
+++ b/src/pip/_vendor/platformdirs/macos.py
@@ -9,14 +9,15 @@ class MacOS(PlatformDirsABC):
"""
Platform directories for the macOS operating system. Follows the guidance from `Apple documentation
<https://developer.apple.com/library/archive/documentation/FileManagement/Conceptual/FileSystemProgrammingGuide/MacOSXDirectories/MacOSXDirectories.html>`_.
- Makes use of the `appname <platformdirs.api.PlatformDirsABC.appname>` and
- `version <platformdirs.api.PlatformDirsABC.version>`.
+ Makes use of the `appname <platformdirs.api.PlatformDirsABC.appname>`,
+ `version <platformdirs.api.PlatformDirsABC.version>`,
+ `ensure_exists <platformdirs.api.PlatformDirsABC.ensure_exists>`.
"""
@property
def user_data_dir(self) -> str:
""":return: data directory tied to the user, e.g. ``~/Library/Application Support/$appname/$version``"""
- return self._append_app_name_and_version(os.path.expanduser("~/Library/Application Support/"))
+ return self._append_app_name_and_version(os.path.expanduser("~/Library/Application Support"))
@property
def site_data_dir(self) -> str:
@@ -25,13 +26,13 @@ class MacOS(PlatformDirsABC):
@property
def user_config_dir(self) -> str:
- """:return: config directory tied to the user, e.g. ``~/Library/Preferences/$appname/$version``"""
- return self._append_app_name_and_version(os.path.expanduser("~/Library/Preferences/"))
+ """:return: config directory tied to the user, same as `user_data_dir`"""
+ return self.user_data_dir
@property
def site_config_dir(self) -> str:
- """:return: config directory shared by the users, e.g. ``/Library/Preferences/$appname``"""
- return self._append_app_name_and_version("/Library/Preferences")
+ """:return: config directory shared by the users, same as `site_data_dir`"""
+ return self.site_data_dir
@property
def user_cache_dir(self) -> str:
@@ -39,6 +40,11 @@ class MacOS(PlatformDirsABC):
return self._append_app_name_and_version(os.path.expanduser("~/Library/Caches"))
@property
+ def site_cache_dir(self) -> str:
+ """:return: cache directory shared by users, e.g. ``/Library/Caches/$appname/$version``"""
+ return self._append_app_name_and_version("/Library/Caches")
+
+ @property
def user_state_dir(self) -> str:
""":return: state directory tied to the user, same as `user_data_dir`"""
return self.user_data_dir